**********************************
Dispersion (`plasmapy.dispersion`)
**********************************

.. py:currentmodule:: plasmapy.dispersion

.. automodapi:: plasmapy.dispersion

Examples
========

.. nbgallery::
   :glob:
   :reversed:

   /notebooks/dispersion/*
